==> tine20-inventory_2019.12.5.tar.bz2: Inventory/js/Inventory-lang-sk-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Inventory **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Inventory'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2017-12-13 11:05+0000\nLast-Translator: sstamer <s.stamer@metaways.de>\nLanguage-Team: Slovak (http://www.transifex.com/tine20/tine20/language/sk/)\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nLanguage: sk\nPlural-Forms: nplurals=4; plural=(n % 1 == 0 && n == 1 ? 0 : n % 1 == 0 && n >= 2 && n <= 4 ? 1 : n % 1 != 0 ? 2: 3);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Inventory item, Inventory items"
: [
  ""
 ,""
 ,""
 ,""

]
, "Inventory item list, Inventory item lists"
: [
  ""
 ,""
 ,""
 ,""

]
, "Name"
: ""

, "Status"
: ""

, "Inventory ID"
: ""

, "Description"
: ""

, "Location"
: ""

, "Invoice date"
: ""

, "Invoice"
: ""

, "Price"
: ""

, "Cost Center"
: ""

, "Warranty"
: ""

, "Item added"
: ""

, "Item removed"
: ""

, "Deprecate"
: ""

, "The active number must be less than or equal total number."
: ""

, "General"
: ""

, "ID"
: ""

, "Enter description"
: ""

, "Added"
: ""

, "Removed"
: ""

, "Total number"
: ""

, "Available number"
: ""

, "Accounting"
: ""

, "Cost center"
: ""

, "Depreciate"
: ""

, "Default Inventory Item Container"
: ""

, "The default container for new items"
: ""

, "Inventory Status Available"
: ""

, "Possible status."
: ""

, "ordered"
: ""

, "available"
: ""

, "defect"
: ""

, "missing"
: ""

, "removed"
: ""

, "unknown"
: ""

, "Inventory CSV import"
: ""

, "Import list (###CURRENTDATE###)"
: ""

, "Items imported on ###CURRENTDATE### at ###CURRENTTIME### by ###USERFULLNAME###"
: ""

, "All Inventory Items"
: ""

, "All existing Inventory Items"
: ""

, "Inventory"
: ""

, "Inventory item"
: ""

, "Inventory item list"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;

==> tine20-inventory_2020.03.4.tar.bz2: Inventory/js/Inventory-lang-sk-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Inventory **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Inventory'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2017-12-13 11:05+0000\nLast-Translator: sstamer <s.stamer@metaways.de>\nLanguage-Team: Slovak (http://www.transifex.com/tine20/tine20/language/sk/)\nLanguage: sk\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=4; plural=(n % 1 == 0 && n == 1 ? 0 : n % 1 == 0 && n >= 2 && n <= 4 ? 1 : n % 1 != 0 ? 2: 3);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Default Inventory Item Container"
: ""

, "The default container for new items"
: ""

, "The active number must be less than or equal total number."
: ""

, "General"
: ""

, "ID"
: ""

, "Name"
: ""

, "Description"
: ""

, "Enter description"
: ""

, "Location"
: ""

, "Added"
: ""

, "Warranty"
: ""

, "Removed"
: ""

, "Total number"
: ""

, "Available number"
: ""

, "Status"
: ""

, "Accounting"
: ""

, "Price"
: ""

, "Cost center"
: ""

, "Invoice"
: ""

, "Invoice date"
: ""

, "Depreciate"
: ""

, "All Inventory Items"
: ""

, "All existing Inventory Items"
: ""

, "Inventory"
: ""

, "Inventory Status Available"
: ""

, "Possible status."
: ""

, "ordered"
: ""

, "available"
: ""

, "defect"
: ""

, "missing"
: ""

, "removed"
: ""

, "unknown"
: ""

, "Inventory item, Inventory items"
: [
  ""
 ,""
 ,""
 ,""

]
, "Inventory item list, Inventory item lists"
: [
  ""
 ,""
 ,""
 ,""

]
, "Inventory ID"
: ""

, "Cost Center"
: ""

, "Item added"
: ""

, "Item removed"
: ""

, "Inventory CSV import"
: ""

, "Import list (###CURRENTDATE###)"
: ""

, "Items imported on ###CURRENTDATE### at ###CURRENTTIME### by ###USERFULLNAME###"
: ""

, "Inventory item"
: ""

, "Inventory item list"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
